@@ -44,9 +44,14 @@ help_text = f"""
 /v详情 昵称关键词或uid  （大写也可以）
 /dmk查用户 昵称关键词或uid  （大写也可以）
 /dmk查直播 昵称关键词或uid  （大写也可以）
+/blg查弹幕 昵称关键词或uid  （大写也可以）
+/blg查入场 昵称关键词或uid  （大写也可以）
+/blg查礼物 昵称关键词或uid  （大写也可以）
+/blg直播记录 昵称关键词或uid  （大写也可以）
+/blg直播间sc 昵称关键词或uid  （大写也可以）
 
 
-调用的相关API源自b站官方接口、danmakus.com、ddstats.ericlamm.xyz和vtbs.fun
+调用的相关API源自b站官方接口、danmakus.com、ddstats.ericlamm.xyz、biligank.com和vtbs.fun
 """.strip()
 
 __plugin_meta__ = PluginMetadata(
@@ -89,6 +94,11 @@ catch_str12 = on_command('查牌子')
 catch_str13 = on_command('V详情', aliases={"v详情"})
 catch_str14 = on_command('dmk查用户', aliases={"DMK查用户", "danmakus查用户"})
 catch_str15 = on_command('dmk查直播', aliases={"DMK查直播", "danmakus查直播"})
+catch_str16 = on_command('blg查弹幕', aliases={"BLG查弹幕", "biligank查弹幕"})
+catch_str17 = on_command('blg查入场', aliases={"BLG查入场", "biligank查入场"})
+catch_str18 = on_command('blg查礼物', aliases={"BLG查礼物", "biligank查礼物"})
+catch_str19 = on_command('blg直播记录', aliases={"BLG直播记录", "biligank直播记录"})
+catch_str20 = on_command('blg直播间sc', aliases={"BLG直播间sc", "blg直播间SC", "BLG直播间SC", "biligank直播间sc"})
 
 
 @catch_str.handle()
@@ -99,14 +109,16 @@ async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
     if 0 == temp["code"]:
         content = temp["uid"]
     else:
-        msg = '\n查询不到用户名为：' + content + ' 的相关信息。'
+        nonebot.logger.info(temp)
+        msg = '\n查询不到用户名为：' + content + ' 的相关信息。\nError code：' + str(temp["code"])
         await catch_str.finish(Message(f'{msg}'), at_sender=True)
 
     # 传入uid获取用户基本信息
     base_info_json = await get_base_info(content)
     # 获取用户信息失败
     if base_info_json['code'] != 0:
-        msg = '\n获取uid：' + content + '，用户信息失败。\n接口返回：\n' + json.dumps(base_info_json, indent=2, ensure_ascii=False)
+        nonebot.logger.info(base_info_json)
+        msg = '\n获取uid：' + content + '，用户信息失败。\nError code：' + str(base_info_json['code'])
         await catch_str.finish(Message(f'{msg}'), at_sender=True)
 
     # 获取用户直播间id
@@ -154,14 +166,16 @@ async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
     if 0 == temp["code"]:
         src_uid = temp["uid"]
     else:
-        msg = '\n查询不到用户名为：' + src_uid + ' 的相关信息。\n接口返回：\n' + temp["resp"]
+        msg = '\n查询不到用户名为：' + src_uid + ' 的相关信息。\nError code：' + str(temp["code"])
+        nonebot.logger.info(temp)
         await catch_str1.finish(Message(f'{msg}'), at_sender=True)
     
     temp = await data_preprocess(tgt_uid)
     if 0 == temp["code"]:
         tgt_uid = temp["uid"]
     else:
-        msg = '\n查询不到用户名为：' + tgt_uid + ' 的相关信息。\n接口返回：\n' + temp["resp"]
+        msg = '\n查询不到用户名为：' + tgt_uid + ' 的相关信息。\nError code：' + str(temp["code"])
+        nonebot.logger.info(temp)
         await catch_str1.finish(Message(f'{msg}'), at_sender=True)
 
     nonebot.logger.debug("src_uid:" + src_uid + " tgt_uid:" + tgt_uid)
@@ -171,11 +185,14 @@ async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
     try:
         # 判断返回代码
         if info_json['code'] != 200:
-            msg = '\n查询出错。接口返回：\n' + json.dumps(info_json, indent=2, ensure_ascii=False)
+            msg = '\n查询出错。Error code：' + str(temp["code"])
+            nonebot.logger.info(info_json)
+
             await catch_str1.finish(Message(f'{msg}'), at_sender=True)
             return
     except (KeyError, TypeError, IndexError) as e:
         msg = '\n果咩，查询信息失败喵~请检查拼写或者是API寄了'
+        nonebot.logger.info(e)
         await catch_str1.finish(Message(f'{msg}'), at_sender=True)
 
     data_len = 0
@@ -204,7 +221,7 @@ async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
         out_str += '\n数据源自：danmakus.com\n'
     # nonebot.logger.info("\n" + out_str)
     except (KeyError, TypeError, IndexError) as e:
-        nonebot.logger.error(e)
+        nonebot.logger.info(e)
         msg = '\n返回数据解析异常，寄~（请查日志排查问题）'
         await catch_str1.finish(Message(f'{msg}'), at_sender=True)
 
@@ -244,7 +261,8 @@ async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
     if 0 == temp["code"]:
         src_uid = temp["uid"]
     else:
-        msg = '\n查询不到用户名为：' + src_uid + ' 的相关信息。\n接口返回：\n' + temp["resp"]
+        nonebot.logger.info(temp)
+        msg = '\n查询不到用户名为：' + src_uid + ' 的相关信息。\nError code：' + str(temp["code"])
         await catch_str11.finish(Message(f'{msg}'), at_sender=True)
 
     nonebot.logger.debug("src_uid:" + src_uid + " tgt_uid:" + tgt_uid)
@@ -257,7 +275,7 @@ async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
             msg = '\n查询出错。接口返回：\n' + json.dumps(info_json, indent=2, ensure_ascii=False)
             await catch_str11.finish(Message(f'{msg}'), at_sender=True)
     except (KeyError, TypeError, IndexError) as e:
-        nonebot.logger.error(e)
+        nonebot.logger.info(e)
         msg = '\n果咩，查询信息失败喵~请检查拼写或者是API寄了'
         await catch_str11.finish(Message(f'{msg}'), at_sender=True)
 
@@ -288,7 +306,7 @@ async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
         out_str += '\n数据源自：danmakus.com\n'
     # nonebot.logger.info("\n" + out_str)
     except (KeyError, TypeError, IndexError) as e:
-        nonebot.logger.error(e)
+        nonebot.logger.info(e)
         msg = '\n返回数据解析异常，寄~（请查日志排查问题）'
         await catch_str11.finish(Message(f'{msg}'), at_sender=True)
 
@@ -308,7 +326,8 @@ async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
     if 0 == temp["code"]:
         content = temp["uid"]
     else:
-        msg = '\n查询不到用户名为：' + content + ' 的相关信息。\n接口返回：\n' + temp["resp"]
+        nonebot.logger.info(temp)
+        msg = '\n查询不到用户名为：' + content + ' 的相关信息。\nError code：' + str(temp["code"])
         await catch_str.finish(Message(f'{msg}'), at_sender=True)
 
     user_info_json = await get_user_info(content)
@@ -319,7 +338,7 @@ async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
             msg = '\n查询用户：' + content + '失败'
             await catch_str2.finish(Message(f'{msg}'), at_sender=True)
     except (KeyError, TypeError, IndexError) as e:
-        nonebot.logger.error(e)
+        nonebot.logger.info(e)
         msg = '\n果咩，查询用户信息失败喵~请检查拼写或者是API寄了'
         await catch_str2.finish(Message(f'{msg}'), at_sender=True)
 
@@ -384,7 +403,8 @@ async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
     if 0 == temp["code"]:
         src_uid = temp["uid"]
     else:
-        msg = '\n查询不到用户名为：' + src_uid + ' 的相关信息。\n接口返回：\n' + temp["resp"]
+        nonebot.logger.info(temp)
+        msg = '\n查询不到用户名为：' + src_uid + ' 的相关信息。\nError code：' + str(temp["code"])
         await catch_str.finish(Message(f'{msg}'), at_sender=True)
 
     info_json = await get_info(src_uid)
@@ -392,10 +412,10 @@ async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
     try:
         # 判断返回代码
         if info_json['code'] != 200:
-            msg = '\n查询用户：' + src_uid + '失败，请检查拼写或者是API寄了'
+            msg = '\n查询用户：' + src_uid + '失败，请检查拼写或者是API寄了\nError code：' + str(info_json["code"])
             await catch_str3.finish(Message(f'{msg}'), at_sender=True)
     except (KeyError, TypeError, IndexError) as e:
-        nonebot.logger.error(e)
+        nonebot.logger.info(e)
         msg = '\n查询用户：' + src_uid + '失败，请检查拼写或者是API寄了'
         await catch_str3.finish(Message(f'{msg}'), at_sender=True)
 
@@ -411,7 +431,7 @@ async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
                 "| 开始时间 | 时长 | 标题 | 弹幕数 | 观看数 | 互动数 | 总收益 |\n" \
                 "| :-----| :-----| :-----| :-----| :-----| :-----| :-----|\n"
     except (KeyError, TypeError, IndexError) as e:
-        nonebot.logger.error(e)
+        nonebot.logger.info(e)
         msg = '\n解析数据异常（请查日志排查问题）'
         await catch_str3.finish(Message(f'{msg}'), at_sender=True)
 
@@ -488,7 +508,8 @@ async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
     if 0 == temp["code"]:
         src_uid = temp["uid"]
     else:
-        msg = '\n查询不到用户名为：' + src_uid + ' 的相关信息。\n接口返回：\n' + temp["resp"]
+        nonebot.logger.info(temp)
+        msg = '\n查询不到用户名为：' + src_uid + ' 的相关信息。\nError code：' + str(temp["code"])
         await catch_str.finish(Message(f'{msg}'), at_sender=True)
 
     live_json = await get_info(src_uid)
@@ -496,10 +517,10 @@ async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
     try:
         # 判断返回代码
         if live_json['code'] != 200:
-            msg = '\n查询用户：' + src_uid + ' 直播信息失败，请检查拼写或者是API寄了'
+            msg = '\n查询用户：' + src_uid + ' 直播信息失败，请检查拼写或者是API寄了\nError code：' + str(live_json["code"])
             await catch_str4.finish(Message(f'{msg}'), at_sender=True)
     except (KeyError, TypeError, IndexError) as e:
-        nonebot.logger.error(e)
+        nonebot.logger.info(e)
         msg = '\n查询用户：' + src_uid + ' 直播信息失败，请检查拼写或者是API寄了'
         await catch_str4.finish(Message(f'{msg}'), at_sender=True)
 
@@ -512,7 +533,7 @@ async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
         totalIncome = str(live_json["data"]["channel"]["totalIncome"])
         totalLivehour = str(round(live_json["data"]["channel"]["totalLiveSecond"] / 60 / 60, 2))
     except (KeyError, TypeError, IndexError) as e:
-        nonebot.logger.error(e)
+        nonebot.logger.info(e)
         msg = '\n查询用户：' + src_uid + '失败,live_id解析失败,可能原因：场次数不对/无此场次'
         await catch_str4.finish(Message(f'{msg}'), at_sender=True)
 
@@ -538,10 +559,10 @@ async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
     info_json = await get_live_info(live_id, income_type)
     try:
         if info_json['code'] != 200:
-            msg = '\n查询用户：' + src_uid + ' 场次数据失败，请检查拼写或者是API寄了'
+            msg = '\n查询用户：' + src_uid + ' 场次数据失败，请检查拼写或者是API寄了\nError code：' + str(temp["code"])
             await catch_str4.finish(Message(f'{msg}'), at_sender=True)
     except (KeyError, TypeError, IndexError) as e:
-        nonebot.logger.error(e)
+        nonebot.logger.info(e)
         msg = '\n查询用户：' + src_uid + ' 场次数据失败，请检查拼写或者是API寄了'
         await catch_str4.finish(Message(f'{msg}'), at_sender=True)
 
@@ -578,17 +599,19 @@ async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
     if 0 == temp["code"]:
         content = temp["uid"]
     else:
-        msg = '\n查询不到UID：' + content + ' 的相关信息。\n接口返回：\n' + temp["resp"]
+        nonebot.logger.info(temp)
+        msg = '\n查询不到UID：' + content + ' 的相关信息。\nError code：' + str(temp["code"])
         await catch_str.finish(Message(f'{msg}'), at_sender=True)
 
     base_info_json = await get_base_info(content)
     try:
         if base_info_json['code'] != 0:
-            msg = '\n获取uid：' + content + '，用户信息失败。\n接口返回：\n' + json.dumps(base_info_json, indent=2, ensure_ascii=False)
+            nonebot.logger.info(base_info_json)
+            msg = '\n获取uid：' + content + '，用户信息失败。\nError code：' + str(base_info_json["code"])
             await catch_str.finish(Message(f'{msg}'), at_sender=True)
         username = base_info_json["card"]["name"]
     except (KeyError, TypeError, IndexError) as e:
-        nonebot.logger.error(e)
+        nonebot.logger.info(e)
         msg = '\n查询UID：' + content + '的用户名失败，请检查拼写/API寄了'
         await catch_str.finish(Message(f'{msg}'), at_sender=True)
 
@@ -597,7 +620,7 @@ async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
     try:
         guard_len = len(guard_info_json)
     except (KeyError, TypeError, IndexError) as e:
-        nonebot.logger.error(e)
+        nonebot.logger.info(e)
         msg = '\n查询UID：' + content + '失败，请检查拼写/没有舰团/API寄了'
         await catch_str.finish(Message(f'{msg}'), at_sender=True)
 
@@ -619,7 +642,7 @@ async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
         out_str += '\n数据源自：vtbs.moe\n'
         # nonebot.logger.info("\n" + out_str)
     except (KeyError, TypeError, IndexError) as e:
-        nonebot.logger.error(e)
+        nonebot.logger.info(e)
         msg = '\n查询UID：' + content + '失败，请检查拼写/没有舰团/API寄了'
         await catch_str.finish(Message(f'{msg}'), at_sender=True)
 
@@ -637,7 +660,7 @@ async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
     try:
         result = info_json['data']['result']
     except (KeyError, TypeError, IndexError) as e:
-        nonebot.logger.error(e)
+        nonebot.logger.info(e)
         msg = '\n查询无结果，请检查拼写或是接口寄了'
         await catch_str6.finish(Message(f'{msg}'), at_sender=True)
 
@@ -672,9 +695,11 @@ async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
 
     try:
         if json1["code"] != 200:
-            msg = '\n请求失败，寄了喵。\n接口返回：\n' + json.dumps(json1, indent=2, ensure_ascii=False)
+            nonebot.logger.info(json1)
+            msg = '\n请求失败，寄了喵。\nError code：' + str(json1["code"])
             await catch_str7.finish(Message(f'{msg}'), at_sender=True)
     except (KeyError, TypeError, IndexError) as e:
+        nonebot.logger.info(e)
         msg = '\n请求解析失败，接口寄了喵'
         await catch_str7.finish(Message(f'{msg}'), at_sender=True)
 
@@ -710,6 +735,7 @@ async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
         # output.save("md2pic.png", format="PNG")
         await catch_str7.send(MessageSegment.image(output))
     except (KeyError, TypeError, IndexError) as e:
+        nonebot.logger.info(e)
         msg = '\n数据解析失败，寄了喵（请查日志排查问题）'
         await catch_str7.finish(Message(f'{msg}'), at_sender=True)
 
@@ -739,10 +765,12 @@ async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
 
     try:
         if json1["code"] != 200:
-            msg = '\n请求失败，寄了喵。\n接口返回：\n' + json.dumps(json1, indent=2, ensure_ascii=False)
+            nonebot.logger.info(json1)
+            msg = '\n请求失败，寄了喵。\n接口返回：\nError code：' + str(json1["code"])
             await catch_str9.finish(Message(f'{msg}'), at_sender=True)
     except (KeyError, TypeError, IndexError) as e:
         msg = '\n请求解析失败，接口寄了喵'
+        nonebot.logger.info(e)
         await catch_str9.finish(Message(f'{msg}'), at_sender=True)
 
     try:
@@ -786,6 +814,7 @@ async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
         # output.save("md2pic.png", format="PNG")
         await catch_str9.send(MessageSegment.image(output))
     except (KeyError, TypeError, IndexError) as e:
+        nonebot.logger.info(e)
         msg = '\n数据解析失败，寄了喵（请查日志排查问题）'
         await catch_str9.finish(Message(f'{msg}'), at_sender=True)
 
@@ -821,9 +850,11 @@ async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
 
     try:
         if json1["code"] != 200:
-            msg = '\n请求失败，寄了喵。\n接口返回：\n' + json.dumps(json1, indent=2, ensure_ascii=False)
+            nonebot.logger.info(json1)
+            msg = '\n请求失败，寄了喵。\nError code：' + str(json1["code"])
             await catch_str10.finish(Message(f'{msg}'), at_sender=True)
     except (KeyError, TypeError, IndexError) as e:
+        nonebot.logger.info(e)
         msg = '\n请求解析失败，接口寄了喵'
         await catch_str10.finish(Message(f'{msg}'), at_sender=True)
 
@@ -871,6 +902,7 @@ async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
         # output.save("md2pic.png", format="PNG")
         await catch_str10.send(MessageSegment.image(output))
     except (KeyError, TypeError, IndexError) as e:
+        nonebot.logger.info(e)
         msg = '\n数据解析失败，寄了喵（请查日志排查问题）'
         await catch_str10.finish(Message(f'{msg}'), at_sender=True)
 
@@ -901,6 +933,7 @@ async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
         output = await md_to_pic(md=out_str, width=700)
         await catch_str10.send(MessageSegment.image(output))
     except (KeyError, TypeError, IndexError) as e:
+        nonebot.logger.info(e)
         msg = '\n查询不到此牌子的数据（可能是数据不足或不存在此牌子喵~）'
         await catch_str12.finish(Message(f'{msg}'), at_sender=True)
 
@@ -913,22 +946,23 @@ async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
     if 0 == temp["code"]:
         content = temp["uid"]
     else:
-        msg = '\n查询不到：' + content + ' 的相关信息。\n接口返回：\n' + temp["resp"]
+        nonebot.logger.info(temp)
+        msg = '\n查询不到：' + content + ' 的相关信息。\nError code：' + str(temp["code"])
         await catch_str13.finish(Message(f'{msg}'), at_sender=True)
 
     try:
         async with get_new_page(viewport={"width": 1415, "height": 1920}) as page:
             await page.goto(
                 "https://vtbs.moe/detail/" + content,
-                timeout=30000,
+                timeout=2 * 60 * 1000,
                 wait_until="networkidle",
             )
             pic = await page.screenshot(full_page=True, path="./data/vtbs.moe_detail.png")
 
         await catch_str13.finish(MessageSegment.image(pic))
     except (KeyError, TypeError, IndexError) as e:
-        msg = '\n查打开页面失败喵（看看后台日志吧）'
         nonebot.logger.info(e)
+        msg = '\n查打开页面失败喵（看看后台日志吧）'
         await catch_str13.finish(Message(f'{msg}'), at_sender=True)
 
 
@@ -940,22 +974,23 @@ async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
     if 0 == temp["code"]:
         content = temp["uid"]
     else:
-        msg = '\n查询不到：' + content + ' 的相关信息。\n接口返回：\n' + temp["resp"]
+        nonebot.logger.info(temp)
+        msg = '\n查询不到：' + content + ' 的相关信息。\nError code：' + str(temp["code"]) 
         await catch_str14.finish(Message(f'{msg}'), at_sender=True)
 
     try:
         async with get_new_page(viewport={"width": 1040, "height": 2500}) as page:
             await page.goto(
                 "https://danmakus.com/user/" + content,
-                timeout=30000,
+                timeout=2 * 60 * 1000,
                 wait_until="networkidle",
             )
-            pic = await page.screenshot(full_page=True, path="./data/vtbs.moe_detail.png")
+            pic = await page.screenshot(full_page=True, path="./data/danmakus.com_user.png")
 
         await catch_str14.finish(MessageSegment.image(pic))
     except (KeyError, TypeError, IndexError) as e:
-        msg = '\n查打开页面失败喵（看看后台日志吧）'
         nonebot.logger.info(e)
+        msg = '\n查打开页面失败喵（看看后台日志吧）'
         await catch_str14.finish(Message(f'{msg}'), at_sender=True)
 
 
@@ -967,25 +1002,170 @@ async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
     if 0 == temp["code"]:
         content = temp["uid"]
     else:
-        msg = '\n查询不到：' + content + ' 的相关信息。\n接口返回：\n' + temp["resp"]
+        nonebot.logger.info(temp)
+        msg = '\n查询不到：' + content + ' 的相关信息。\nError code：' + str(temp["code"])
         await catch_str15.finish(Message(f'{msg}'), at_sender=True)
 
     try:
         async with get_new_page(viewport={"width": 850, "height": 2000}) as page:
             await page.goto(
                 "https://danmakus.com/channel/" + content,
-                timeout=30000,
+                timeout=2 * 60 * 1000,
                 wait_until="networkidle",
             )
-            pic = await page.screenshot(full_page=True, path="./data/vtbs.moe_detail.png")
+            pic = await page.screenshot(full_page=True, path="./data/danmakus.com_channel.png")
 
         await catch_str15.finish(MessageSegment.image(pic))
     except (KeyError, TypeError, IndexError) as e:
-        msg = '\n查打开页面失败喵（看看后台日志吧）'
         nonebot.logger.info(e)
+        msg = '\n查打开页面失败喵（看看后台日志吧）'
         await catch_str15.finish(Message(f'{msg}'), at_sender=True)
 
 
+@catch_str16.handle()
+async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
+    content = msg.extract_plain_text()
+
+    temp = await data_preprocess(content)
+    if 0 == temp["code"]:
+        content = temp["uid"]
+    else:
+        nonebot.logger.info(temp)
+        msg = '\n查询不到：' + content + ' 的相关信息。\nError code：' + str(temp["code"])
+        await catch_str16.finish(Message(f'{msg}'), at_sender=True)
+
+    try:
+        async with get_new_page(viewport={"width": 800, "height": 200}) as page:
+            await page.goto(
+                "https://biligank.com/live/ablive_dm?offset=0&uid=" + content,
+                timeout=2 * 60 * 1000,
+                wait_until="networkidle",
+            )
+            pic = await page.screenshot(full_page=True, path="./data/biligank.com_ablive_dm.png")
+
+        await catch_str16.finish(MessageSegment.image(pic))
+    except (KeyError, TypeError, IndexError) as e:
+        nonebot.logger.info(e)
+        msg = '\n查打开页面失败喵（看看后台日志吧）'
+        await catch_str16.finish(Message(f'{msg}'), at_sender=True)
+
+
+# blg查入场
+@catch_str17.handle()
+async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
+    content = msg.extract_plain_text()
+
+    temp = await data_preprocess(content)
+    if 0 == temp["code"]:
+        content = temp["uid"]
+    else:
+        nonebot.logger.info(temp)
+        msg = '\n查询不到：' + content + ' 的相关信息。\nError code：' + str(temp["code"])
+        await catch_str17.finish(Message(f'{msg}'), at_sender=True)
+
+    try:
+        async with get_new_page(viewport={"width": 800, "height": 200}) as page:
+            await page.goto(
+                "https://biligank.com/live/ablive_en?offset=0&uid=" + content,
+                timeout=2 * 60 * 1000,
+                wait_until="networkidle",
+            )
+            pic = await page.screenshot(full_page=True, path="./data/biligank.com_ablive_en.png")
+
+        await catch_str17.finish(MessageSegment.image(pic))
+    except (KeyError, TypeError, IndexError) as e:
+        nonebot.logger.info(e)
+        msg = '\n查打开页面失败喵（看看后台日志吧）'
+        await catch_str17.finish(Message(f'{msg}'), at_sender=True)
+
+
+# blg查礼物
+@catch_str18.handle()
+async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
+    content = msg.extract_plain_text()
+
+    temp = await data_preprocess(content)
+    if 0 == temp["code"]:
+        content = temp["uid"]
+    else:
+        nonebot.logger.info(temp)
+        msg = '\n查询不到：' + content + ' 的相关信息。\nError code：' + str(temp["code"])
+        await catch_str18.finish(Message(f'{msg}'), at_sender=True)
+
+    try:
+        async with get_new_page(viewport={"width": 800, "height": 200}) as page:
+            await page.goto(
+                "https://biligank.com/live/ablive_gf?offset=0&uid=" + content,
+                timeout=2 * 60 * 1000,
+                wait_until="networkidle",
+            )
+            pic = await page.screenshot(full_page=True, path="./data/biligank.com_ablive_gf.png")
+
+        await catch_str18.finish(MessageSegment.image(pic))
+    except (KeyError, TypeError, IndexError) as e:
+        nonebot.logger.info(e)
+        msg = '\n查打开页面失败喵（看看后台日志吧）'
+        await catch_str18.finish(Message(f'{msg}'), at_sender=True)
+
+
+# blg直播记录
+@catch_str19.handle()
+async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
+    content = msg.extract_plain_text()
+
+    temp = await data_preprocess(content)
+    if 0 == temp["code"]:
+        content = temp["uid"]
+    else:
+        nonebot.logger.info(temp)
+        msg = '\n查询不到：' + content + ' 的相关信息。\nError code：' + str(temp["code"])
+        await catch_str19.finish(Message(f'{msg}'), at_sender=True)
+
+    try:
+        async with get_new_page(viewport={"width": 1000, "height": 200}) as page:
+            await page.goto(
+                "https://biligank.com/live/tp?offset=0&uid=" + content,
+                timeout=2 * 60 * 1000,
+                wait_until="networkidle",
+            )
+            pic = await page.screenshot(full_page=True, path="./data/biligank.com_ablive_sc.png")
+
+        await catch_str19.finish(MessageSegment.image(pic))
+    except (KeyError, TypeError, IndexError) as e:
+        nonebot.logger.info(e)
+        msg = '\n查打开页面失败喵（看看后台日志吧）'
+        await catch_str19.finish(Message(f'{msg}'), at_sender=True)
+
+
+# blg直播间sc
+@catch_str20.handle()
+async def _(bot: Bot, event: Event, msg: Message = CommandArg()):
+    content = msg.extract_plain_text()
+
+    temp = await data_preprocess(content)
+    if 0 == temp["code"]:
+        content = temp["uid"]
+    else:
+        nonebot.logger.info(temp)
+        msg = '\n查询不到：' + content + ' 的相关信息。\nError code：' + str(temp["code"])
+        await catch_str20.finish(Message(f'{msg}'), at_sender=True)
+
+    try:
+        async with get_new_page(viewport={"width": 1000, "height": 200}) as page:
+            await page.goto(
+                "https://biligank.com/live/ablive_sc?offset=0&uid=" + content,
+                timeout=2 * 60 * 1000,
+                wait_until="networkidle",
+            )
+            pic = await page.screenshot(full_page=True, path="./data/biligank.com_ablive_sc.png")
+
+        await catch_str20.finish(MessageSegment.image(pic))
+    except (KeyError, TypeError, IndexError) as e:
+        nonebot.logger.info(e)
+        msg = '\n查打开页面失败喵（看看后台日志吧）'
+        await catch_str20.finish(Message(f'{msg}'), at_sender=True)
+
+
 # 获取营收榜单信息 传入 日/周/月榜 和 数量
 async def get_revenue(date_range, size):
     if date_range == '日榜':
@@ -1026,7 +1206,7 @@ async def get_incfans(date_range, size):
     return ret
 
 
-# 数据预处理 返回uid
+# 数据预处理 返回uid 如果返回-1为异常 -2表示搜索成功但没有相关用户
 async def data_preprocess(content):
     temp = {"code": 0, "uid": content, "resp": ""}
     # 由于逻辑问题 查uid时需要追加(以:或：或uid:或UID:或uid：打头)在命令后
@@ -1052,9 +1232,19 @@ async def data_preprocess(content):
         # nonebot.logger.info(info_json)
 
         try:
-            result = info_json['data']['result']
-            # 只获取第一个搜索结果的数据
-            temp["uid"] = str(result[0]["mid"])
+            if info_json['code'] != 0:
+                temp["code"] = -1
+                nonebot.logger.info(info_json)
+                return temp
+
+            if "result" in info_json['data']:
+                result = info_json['data']['result']
+                # 只获取第一个搜索结果的数据
+                temp["uid"] = str(result[0]["mid"])
+                return temp
+            
+            temp["code"] = -2
+            nonebot.logger.info(info_json)
             return temp
         except (KeyError, TypeError, IndexError) as e:
             temp["resp"] = json.dumps(info_json, ensure_ascii=False)
